import nltk
from nltk import load_parser

####
# we start with a parser that does syntax only
cp = load_parser('grammar0.fcfg')

# here is what we can do with it
inputs = ["Vincent sleeps", "Vincent loves Mia"]


for sentence in inputs:
    # parse the sentence with the grammar from grammar1
    trees = list(cp.parse(nltk.word_tokenize(sentence)))

    # output sentence, whole parse, and
    # semantics of the tree root
    print("\n\nsentence:", sentence, "\n")
    for t in trees:
        print("parse:", t, "\n")


# we can also get a graphical representation of a tree
tree = list(cp.parse(nltk.word_tokenize("Vincent sleeps")))[0]
tree.draw()

#############3
# Now we move to a grammar with (rudimentary) semantics

cp = load_parser('grammar1.fcfg')

inputs = ["Vincent sleeps", "Vincent loves Mia"]

for sentence in inputs:
    # parse the sentence with the grammar from grammar1
    trees = list(cp.parse(nltk.word_tokenize(sentence)))

    # output sentence, whole parse, and
    # semantics of the tree root
    print("\n\nsentence:", sentence, "\n")
    for t in trees:
        print("parse:", t, "\n")
        print("semantics:", t.label()['SEM'])
        
              
#######
# Now for a more complex grammar
cp = load_parser('grammar2.fcfg')

inputs = ["Vincent sleeps", "Mia loves every robber"]


for sentence in inputs:
    # parse the sentence with the grammar from grammar1
    trees = list(cp.parse(nltk.word_tokenize(sentence)))

    # output sentence, whole parse, and
    # semantics of the tree root
    print("\n\nsentence:", sentence, "\n")
    for t in trees:
        print("parse:", t, "\n")
        print("semantics:", t.label()['SEM'])


################
# Next: Here is the grammar from 
# Blackburn and Bos
# chapter 2.
# It currently does not have semantics -- can you add that?

cp = load_parser('grammar_bb.fcfg')

inputs = ["Mia knows every owner of a bar", "Vincent or Mia dances", "every boxer that kills a criminal loves a woman", "Vincent doesnt love a boxer or criminal that snorts", "she doesnt love a boxer or criminal that snorts and dances", "a boxer snorts", "he collapses", "Mia is a woman", "Vincent is not a boxer"]

for sentence in inputs:
    # parse the sentence with the grammar from grammar1
    trees = list(cp.parse(nltk.word_tokenize(sentence)))

    # output sentence, whole parse, and
    # semantics of the tree root
    print("\n\nsentence:", sentence, "\n")
    for t in trees:
        print("parse:", t, "\n")
